@@ -1,3 +1,4 @@
+"""Bootstrap module for initializing the Gito application environment."""
 import os
 import sys
 import io
@@ -7,8 +8,9 @@ from pathlib import Path
 
 import microcore as mc
 
-from .utils import is_running_in_github_action
-from .constants import HOME_ENV_PATH, EXECUTABLE, PROJECT_GITO_FOLDER
+from .utils.git_platform.gitlab import is_running_in_gitlab_ci
+from .utils.git_platform.github import is_running_in_github_action
+from .constants import HOME_ENV_PATH, EXECUTABLE, PROJECT_GITO_FOLDER, DEFAULT_MAX_CONCURRENT_TASKS
 from .env import Env
 
 
@@ -65,6 +67,8 @@ def bootstrap(verbosity: int = 1):
                 Path(__file__).parent / "tpl"
             ],
         )
+        if mc.config().MAX_CONCURRENT_TASKS is None:
+            mc.config().MAX_CONCURRENT_TASKS = DEFAULT_MAX_CONCURRENT_TASKS
         if verbosity > 1:
             mc.logging.LoggingConfig.STRIP_REQUEST_LINES = None
         else:
@@ -82,8 +86,16 @@ def bootstrap(verbosity: int = 1):
                 ref = ref.split(".github/workflows/")[-1]
                 ref = f" (.github/workflows/{ref})"
             msg += (
-                f"\nPlease check your GitHub Action Secrets "
-                f"and `env` configuration section of the corresponding workflow step{ref}."
+                f"\nPlease check your GitHub Action secrets "
+                f"and `env` configuration section of the corresponding workflow step{ref}.\n"
+                f"See https://github.com/Nayjest/Gito/blob/main/documentation/github_setup.md "
+                f"for details."
+            )
+        elif is_running_in_gitlab_ci():
+            # @TODO add link to GitLab setup article
+            msg += (
+                "\nPlease check your GitLab CI/CD Variables "
+                "and `variables` configuration section of the corresponding job."
             )
         else:
             msg += (
